# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schema/context.yaml

"""Context attribute keys for Highflame Cedar policies."""

class ContextKey:
    """Context attribute keys for Cedar policy evaluation."""

    pass  # No context attributes defined
