# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schemas/overwatch/context.json

"""Context attribute keys for Overwatch Overwatch (Guardian) IDE security & policy enforcement."""

class OverwatchContextKey:
    """Context keys for Overwatch policy evaluation."""

    CONTAINS_SECRETS: str = "contains_secrets"
    CONTENT: str = "content"
    CRIME_SCORE: str = "crime_score"
    CWD: str = "cwd"
    EVENT: str = "event"
    HATE_SPEECH_SCORE: str = "hate_speech_score"
    HIGHEST_SEVERITY: str = "highest_severity"
    INDIRECT_INJECTION_SCORE: str = "indirect_injection_score"
    INJECTION_CONFIDENCE: str = "injection_confidence"
    JAILBREAK_CONFIDENCE: str = "jailbreak_confidence"
    MAX_THREAT_SEVERITY: str = "max_threat_severity"
    MCP_SERVER: str = "mcp_server"
    MCP_SERVER_VERIFIED: str = "mcp_server_verified"
    MCP_TOOL: str = "mcp_tool"
    PATH: str = "path"
    PII_CONFIDENCE: str = "pii_confidence"
    PROFANITY_SCORE: str = "profanity_score"
    PROMPT_TEXT: str = "prompt_text"
    RESPONSE_CONTENT: str = "response_content"
    RUG_PULL_SCORE: str = "rug_pull_score"
    SEXUAL_SCORE: str = "sexual_score"
    SOURCE: str = "source"
    THREAT_CATEGORIES: str = "threat_categories"
    THREAT_COUNT: str = "threat_count"
    THREAT_TYPES: str = "threat_types"
    TOOL_NAME: str = "tool_name"
    TOOL_POISONING_SCORE: str = "tool_poisoning_score"
    USER_EMAIL: str = "user_email"
    VIOLENCE_SCORE: str = "violence_score"
    WEAPONS_SCORE: str = "weapons_score"
    WORKSPACE_ROOT: str = "workspace_root"
    YARA_THREATS: str = "yara_threats"
