# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schemas/guardrails/context.json

"""Context attribute keys for Guardrails Guardrails (Shield) content security & policy enforcement for LLM applications."""

class GuardrailsContextKey:
    """Context keys for Guardrails policy evaluation."""

    BUDGET_EXCEEDED: str = "budget_exceeded"
    BUDGET_REMAINING_PCT: str = "budget_remaining_pct"
    CONTAINS_INVISIBLE_CHARS: str = "contains_invisible_chars"
    CONTAINS_SECRETS: str = "contains_secrets"
    CONTENT_TOPICS: str = "content_topics"
    CONTENT_TYPE: str = "content_type"
    CRIME_SCORE: str = "crime_score"
    DETECTOR_COUNT: str = "detector_count"
    DIRECTION: str = "direction"
    HATE_SPEECH_SCORE: str = "hate_speech_score"
    INJECTION_SCORE: str = "injection_score"
    INJECTION_TYPE: str = "injection_type"
    INVISIBLE_CHARS_SCORE: str = "invisible_chars_score"
    JAILBREAK_SCORE: str = "jailbreak_score"
    LOOP_COUNT: str = "loop_count"
    LOOP_DETECTED: str = "loop_detected"
    LOOP_TOOL: str = "loop_tool"
    MCP_SERVER: str = "mcp_server"
    MCP_SERVER_VERIFIED: str = "mcp_server_verified"
    MCP_TOOL: str = "mcp_tool"
    PATTERN_TYPE: str = "pattern_type"
    PII_COUNT: str = "pii_count"
    PII_DETECTED: str = "pii_detected"
    PII_TYPES: str = "pii_types"
    PROFANITY_SCORE: str = "profanity_score"
    REQUEST_ID: str = "request_id"
    SECRET_COUNT: str = "secret_count"
    SECRET_TYPES: str = "secret_types"
    SEQUENCE_RISK: str = "sequence_risk"
    SEXUAL_SCORE: str = "sexual_score"
    SUSPICIOUS_PATTERN: str = "suspicious_pattern"
    TIMESTAMP: str = "timestamp"
    TOOL_CATEGORY: str = "tool_category"
    TOOL_IS_BUILTIN: str = "tool_is_builtin"
    TOOL_IS_SENSITIVE: str = "tool_is_sensitive"
    TOOL_NAME: str = "tool_name"
    TOOL_RISK_SCORE: str = "tool_risk_score"
    TOPIC_CONFIDENCE: str = "topic_confidence"
    VIOLENCE_SCORE: str = "violence_score"
    WEAPONS_SCORE: str = "weapons_score"
